@@ -27,17 +27,19 @@ void TestSuite::run(TestResult *result)
 			break;
 
 		Test *test = *it;
+		if (!setup().empty())
+			test->addSetup(setup());
 		test->run(result);
 	}
 }
 
 
 // Counts the number of test cases that will be run by this test.
-int TestSuite::countTestCases()
+int TestSuite::countTestCases() const
 {
 	int count = 0;
 
-	for (std::vector<Test*>::iterator it = _tests.begin (); it != _tests.end (); ++it)
+	for (std::vector<Test*>::const_iterator it = _tests.begin (); it != _tests.end (); ++it)
 		count += (*it)->countTestCases();
 
 	return count;
